( cd usr/lib ; rm -rf libwmflite-0.2.so.7 )
( cd usr/lib ; ln -sf libwmflite-0.2.so.7.0.1 libwmflite-0.2.so.7 )
( cd usr/lib ; rm -rf libwmflite.so )
( cd usr/lib ; ln -sf libwmflite-0.2.so.7.0.1 libwmflite.so )
( cd usr/lib ; rm -rf libwmf-0.2.so.7 )
( cd usr/lib ; ln -sf libwmf-0.2.so.7.1.0 libwmf-0.2.so.7 )
( cd usr/lib ; rm -rf libwmf.so )
( cd usr/lib ; ln -sf libwmf-0.2.so.7.1.0 libwmf.so )
